gawk-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gawk-diffs] [SCM] gawk branch, feature/api-parser, updated. gawk-4.1.0-


From: Arnold Robbins
Subject: [gawk-diffs] [SCM] gawk branch, feature/api-parser, updated. gawk-4.1.0-2449-gfeb12ba
Date: Thu, 9 Mar 2017 15:09:27 -0500 (EST)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "gawk".

The branch, feature/api-parser has been updated
       via  feb12baf11e39f60e57b988d29aa96bda4dddcff (commit)
      from  de08cb2b36073987fe86dfcc8c66c2f0e8711ef8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.sv.gnu.org/cgit/gawk.git/commit/?id=feb12baf11e39f60e57b988d29aa96bda4dddcff

commit feb12baf11e39f60e57b988d29aa96bda4dddcff
Author: Arnold D. Robbins <address@hidden>
Date:   Thu Mar 9 22:09:09 2017 +0200

    Minor style edits in field.c.

diff --git a/ChangeLog b/ChangeLog
index e8bd1f5..a5fa974 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2017-03-09         Arnold D. Robbins     <address@hidden>
+
+       * field.c: Minor style edits.
+
 2017-03-06         Andrew J. Schorr     <address@hidden>
 
        * field.c (normal_parse_field): Renamed from save_parse_field to reflect
diff --git a/field.c b/field.c
index 276669f..5bdc05f 100644
--- a/field.c
+++ b/field.c
@@ -322,12 +322,9 @@ set_record(const char *buf, int cnt, const int *fw)
                                parse_field = api_parse_field;
                                update_PROCINFO_str("FS", "API");
                        }
-               }
-               else {
-                       if (parse_field != normal_parse_field) {
-                               parse_field = normal_parse_field;
-                               update_PROCINFO_str("FS", 
current_field_sep_str());
-                       }
+               } else if (parse_field != normal_parse_field) {
+                       parse_field = normal_parse_field;
+                       update_PROCINFO_str("FS", current_field_sep_str());
                }
        }
 
@@ -789,6 +786,7 @@ fw_parse_field(long up_to,  /* parse only up to this field 
number */
  *
  * This is called from get_field() via (*parse_field)().
  */
+
 static long
 api_parse_field(long up_to,    /* parse only up to this field number */
        char **buf,     /* on input: string to parse; on output: point to start 
next */
@@ -1350,7 +1348,7 @@ choose_fs_function:
                FS_regexp = FS_re_yes_case;
 }
 
-/* current_field_sep --- return what field separator is */
+/* current_field_sep --- return the field separator type */
 
 field_sep_type
 current_field_sep()
@@ -1365,7 +1363,7 @@ current_field_sep()
                return Using_FS;
 }
 
 /* current_field_sep --- return what field separator is */
 
 const char *
 current_field_sep_str()

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog |  4 ++++
@@ -1365,7 +1363,7 @@ current_field_sep()
 }
 
-/* current_field_sep --- return what field separator is */
+/* current_field_sep_str --- return the field separator type as a string */
 
 const char *
 field.c   | 14 ++++++--------
 2 files changed, 10 insertions(+), 8 deletions(-)


hooks/post-receive
-- 
gawk



reply via email to

[Prev in Thread] Current Thread [Next in Thread]